contentToString method
Returns a string representation of the contents of the specified array as if it is List.
Implementation
@Deprecated('')
String contentToString() => join(', ');
Returns a string representation of the contents of the specified array as if it is List.
@Deprecated('')
String contentToString() => join(', ');