find method
Returns the first element matching the given predicate, or null if no such element was found.
Implementation
T? find(bool Function(T? it) predicate) =>
cast<T?>().firstWhere(predicate, orElse: () => null);
Returns the first element matching the given predicate, or null if no such element was found.
T? find(bool Function(T? it) predicate) =>
cast<T?>().firstWhere(predicate, orElse: () => null);