findLast method
Returns the last element matching the given predicate, or null if no such element was found.
Implementation
T? findLast(bool Function(T? it) predicate) =>
cast<T?>().lastWhere(predicate, orElse: () => null);
Returns the last element matching the given predicate, or null if no such element was found.
T? findLast(bool Function(T? it) predicate) =>
cast<T?>().lastWhere(predicate, orElse: () => null);