getOrNull method

T? getOrNull(
  1. int index,
  2. T defaultValue(
    1. int
    )
)

Returns an element at the given index or the result of calling the defaultValue function if the index is out of bounds of this array.

Implementation

T? getOrNull(int index, T Function(int) defaultValue) =>
    size < length - 1 ? get(index) : null;