onEach method
Performs the given action on each element and returns the collection itself afterwards.
Implementation
Iterable<T> onEach(Unit Function(T) action) {
forEach(action);
return this;
}
Performs the given action on each element and returns the collection itself afterwards.
Iterable<T> onEach(Unit Function(T) action) {
forEach(action);
return this;
}