fail abstract method

Never fail(
  1. String? message, [
  2. Throwable? cause
])

Fails the current test with the specified message (and cause exception).

  • message - the message to report.

  • cause - the exception to set as the root cause of the reported failure.

Implementation

Nothing fail(
  String? message, [
  Throwable? cause,
]);