AsserterResult class abstract interface

Describes the result of an assertion execution.

Properties

actual Any?
no setter
expected Any?
no setter
hashCode int
The hash code for this object.
no setterinherited
lazyMessage String? Function()
no setter
result Boolean
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited