AssociatedObjectKey class final

Makes the annotated annotation class an associated object key.

An associated object key annotation should have single KClass parameter. When applied to a class with reference to an object declaration as an argument, it binds the object to the class, making this binding discoverable at runtime using findAssociatedObject.

Annotations
  • @Target([AnnotationTarget.ANNOTATION_CLASS])

Constructors

AssociatedObjectKey()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited