operator []= method
Atomically sets the value of the element at the given index to the newValue.
Implementation
external operator []=(Int index, T newValue);
Atomically sets the value of the element at the given index to the newValue.
external operator []=(Int index, T newValue);