Boolean typedef
Boolean = bool
Represents a value which is either true or false.
On the JVM, non-nullable values of this type are represented as values of the primitive type boolean.
Implementation
typedef Boolean = bool;