Byte typedef
Byte = int
Represents a 8-bit signed integer.
On the JVM, non-nullable values of this type are represented as values of the primitive type byte.
Implementation
typedef Byte = int;
Represents a 8-bit signed integer.
On the JVM, non-nullable values of this type are represented as values of the primitive type byte.
typedef Byte = int;