safeCast<T> method

T? safeCast<T>()

Casts the given value to the class represented by this T object.

Returns null if the value is null or if it is not an instance of this class.

Implementation

T? safeCast<T>() => this as T?;