unsafeCast<T> method

T unsafeCast<T>()

Casts the given value to the class represented by this T object.

Throws an exception if the value is null or if it is not an instance of this class.

Implementation

T unsafeCast<T>() => this as T;