ComparisonUtils<T extends Comparable<T>> extension

on

Methods

coerceAtLeast(T minimumValue) Comparable<T>

Available on Comparable<T>, provided by the ComparisonUtils extension

Ensures that this value is not less than the specified minimumValue.
coerceAtMost(T maximumValue) Comparable<T>

Available on Comparable<T>, provided by the ComparisonUtils extension

Ensures that this value is not greater than the specified maximumValue.
coerceIn(T minimumValue, T maximumValue) Comparable<T>

Available on Comparable<T>, provided by the ComparisonUtils extension

Ensures that this value lies between the minimumValue and maximumValue.

Operators

operator <(T other) bool

Available on Comparable<T>, provided by the ComparisonUtils extension

operator <=(T other) bool

Available on Comparable<T>, provided by the ComparisonUtils extension

operator >(T other) bool

Available on Comparable<T>, provided by the ComparisonUtils extension

operator >=(T other) bool

Available on Comparable<T>, provided by the ComparisonUtils extension