coerceAtLeast method
Ensures that this value is not less than the specified minimumValue.
Implementation
Comparable<T> coerceAtLeast(T minimumValue) {
return this >= minimumValue ? this : minimumValue;
}
Ensures that this value is not less than the specified minimumValue.
Comparable<T> coerceAtLeast(T minimumValue) {
return this >= minimumValue ? this : minimumValue;
}