coerceAtMost method
Ensures that this value is not greater than the specified maximumValue.
Implementation
Comparable<T> coerceAtMost(T maximumValue) {
return this > maximumValue ? maximumValue : this;
}
Ensures that this value is not greater than the specified maximumValue.
Comparable<T> coerceAtMost(T maximumValue) {
return this > maximumValue ? maximumValue : this;
}