hiddenSince property
The version, since which the annotated declaration should not be available in code.
Implementation
final String hiddenSince;
The version, since which the annotated declaration should not be available in code.
final String hiddenSince;