DetachedObjectGraph<T> class

Detached object graph encapsulates transferrable detached subgraph which cannot be accessed externally, until it is attached with the attach extension function.

Available extensions

Constructors

DetachedObjectGraph.fromPointer(COpaquePointer? pointer)
Restores detached object graph from the value stored earlier in a C raw pointer.
factory
DetachedObjectGraph.fromProducer({TransferMode mode = TransferMode.SAFE, required T producer()})
Creates stable pointer to object, ensuring associated object subgraph is disjoint in specified mode (TransferMode.SAFE by default).
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
mode TransferMode?
final
pointer → COpaquePointer?
final
producer → T Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

asCPointer() → COpaquePointer?
Returns raw C pointer value, usable for interoperability with C scenarious.
attach<T>() → T

Available on DetachedObjectGraph, provided by the NativeConcurrentDetachedObjectGraphExtension extension

Attaches previously detached object subgraph created by DetachedObjectGraph.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited