FreezingException class

Exception thrown whenever freezing is not possible.

Inheritance

Constructors

FreezingException({required Any toFreeze, required Any blocker})
Exception thrown whenever freezing is not possible.
const

Properties

blocker Any
An object preventing freezing, usually one marked with ensureNeverFrozen earlier.
final
cause Throwable?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toFreeze Any
An object intended to be frozen.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited