value property
T
get
value
The result of the future computation.
Blocks execution until the future is ready.
Second attempt to get will result in an error.
Implementation
external T get value;
The result of the future computation.
Blocks execution until the future is ready.
Second attempt to get will result in an error.
external T get value;