targetHeapUtilization property
What fraction of the Kotlin heap should be populated.
Only used if autotune is true.
See targetHeapBytes for more details.
Implementation
external Long targetHeapUtilization;
What fraction of the Kotlin heap should be populated.
Only used if autotune is true.
See targetHeapBytes for more details.
external Long targetHeapUtilization;