firstPauseEndTimeNs property
Time, when mutator threads are unsuspended for the first time,
mesured by kotlin.system.getTimeNanos.
Implementation
final Long firstPauseEndTimeNs;
Time, when mutator threads are unsuspended for the first time,
mesured by kotlin.system.getTimeNanos.
final Long firstPauseEndTimeNs;