firstPauseRequestTimeNs property

Long firstPauseRequestTimeNs
final

Time, when the garbage collector thread requested suspension of mutator threads for the first time, mesured by kotlin.system.getTimeNanos.

Implementation

final Long firstPauseRequestTimeNs;