firstPauseStartTimeNs property
Time, when mutator threads are suspended for the first time,
mesured by kotlin.system.getTimeNanos.
Implementation
final Long firstPauseStartTimeNs;
Time, when mutator threads are suspended for the first time,
mesured by kotlin.system.getTimeNanos.
final Long firstPauseStartTimeNs;