secondPauseEndTimeNs property
Time, when mutator threads are unsuspended for the second time,
mesured by kotlin.system.getTimeNanos.
Implementation
final Long? secondPauseEndTimeNs;
Time, when mutator threads are unsuspended for the second time,
mesured by kotlin.system.getTimeNanos.
final Long? secondPauseEndTimeNs;