secondPauseRequestTimeNs property

Long? secondPauseRequestTimeNs
final

Time, when the garbage collector thread requested suspension of mutator threads for the second time, mesured by kotlin.system.getTimeNanos.

Implementation

final Long? secondPauseRequestTimeNs;