secondPauseStartTimeNs property
Time, when mutator threads are suspended for the second time,
mesured by kotlin.system.getTimeNanos.
Implementation
final Long? secondPauseStartTimeNs;
Time, when mutator threads are suspended for the second time,
mesured by kotlin.system.getTimeNanos.
final Long? secondPauseStartTimeNs;