sweepStatistics property
Sweeping statistics separated by memory pools.
The set of memory pools depends on the collector implementation.
Can be empty, if collection is in progress.
Implementation
final Map<String, SweepStatistics> sweepStatistics;
Sweeping statistics separated by memory pools.
The set of memory pools depends on the collector implementation.
Can be empty, if collection is in progress.
final Map<String, SweepStatistics> sweepStatistics;