Int typedef
Int = int
Represents a 32-bit signed integer.
On the JVM, non-nullable values of this type are represented as values of the primitive type int.
Implementation
typedef Int = int;
Represents a 32-bit signed integer.
On the JVM, non-nullable values of this type are represented as values of the primitive type int.
typedef Int = int;