InvalidMutabilityException class

Exception thrown whenever we attempt to mutate frozen objects.

Inheritance

Constructors

InvalidMutabilityException({String? message})
Exception thrown whenever we attempt to mutate frozen objects.
const

Properties

cause Throwable?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited