JUnitAsserter class sealed

Implements kotlin.test assertions by delegating them to org.junit.Assert class.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

assertEquals(String? message, Any? expected, Any? actual) → void
Asserts that the specified values are equal.
inherited
assertNotEquals(String? message, Any? illegal, Any? actual) → void
Asserts that the specified values are not equal.
inherited
assertNotNull(String? message, Any? actual) → void
Asserts that the specified value is not null.
inherited
assertNotSame(String? message, Any? illegal, Any? actual) → void
Asserts that the specified values are not the same instance.
inherited
assertNull(String? message, Any? actual) → void
Asserts that the specified value is null.
inherited
assertSame(String? message, Any? illegal, Any? actual) → void
Asserts that the specified values are the same instance.
inherited
assertTrue(Boolean actual, {String? message, String? lazyMessage()}) → void
Asserts that the specified value is true.
inherited
fail(String? message, [Throwable? cause]) → Never
Fails the current test with the specified message (and cause exception).
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited