JUnitContributor class final

Provides JUnitAsserter if org.junit.Assert is found in the classpath.

Implemented types

Constructors

JUnitContributor()
Provides JUnitAsserter if org.junit.Assert is found in the classpath.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

contribute() Asserter?
Provides Asserter instance or null depends on the current context.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited