JvmName class final

Specifies the name for the Java class or method which is generated from this element.

See the Kotlin language documentation for more information.

Annotations
  • @Target([AnnotationTarget.FILE, AnnotationTarget.FUNCTION, AnnotationTarget.PROPERTY_GETTER, AnnotationTarget.PROPERTY_SETTER])

Constructors

JvmName(String name)
Specifies the name for the Java class or method which is generated from this element.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
The name of the element.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited