JvmName constructor
const
JvmName(
- String name
Specifies the name for the Java class or method which is generated from this element.
Implementation
const JvmName(this.name);
Specifies the name for the Java class or method which is generated from this element.
const JvmName(this.name);