JvmOverload class final
Instructs the Kotlin compiler to generate overloads for this function that substitute default parameter values.
If a method has N parameters and M of which have default values,
M overloads are generated: the first one takes N-1 parameters
(all but the last one that takes a default value),
the second takes N-2 parameters, and so on.
- Annotations
-
- @Target([AnnotationTarget.FUNCTION, AnnotationTarget.CONSTRUCTOR])
Constructors
- JvmOverload()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited