JvmRecord class final

Instructs compiler to mark the class as a record and generate relevant toString/equals/hashCode methods.

Annotations
  • @Target([AnnotationTarget.CLASS])

Constructors

JvmRecord()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited