visibility property
KVisibility?
get
visibility
Visibility of this callable, or null if its visibility cannot be represented in Kotlin.
Implementation
KVisibility? get visibility;
Visibility of this callable, or null if its visibility cannot be represented in Kotlin.
KVisibility? get visibility;