instanceParameter property

KParameter? get instanceParameter

Returns a parameter representing the this instance needed to call this callable, or null if this callable is not a member of a class and thus doesn't take such parameter.

Implementation

KParameter? get instanceParameter => parameters
    .singleOrNull((element) => element?.kind == KParameterKind.INSTANCE);