isCompanion property
Boolean
get
isCompanion
Returns true if this class is a companion object.
See the Kotlin language documentation for more information.
Implementation
Boolean get isCompanion;
Returns true if this class is a companion object.
See the Kotlin language documentation for more information.
Boolean get isCompanion;