index property
Int
get
index
0-based index of this parameter in the parameter list of its containing callable.
Implementation
Int get index;
0-based index of this parameter in the parameter list of its containing callable.
Int get index;