KParameter class abstract interface

Represents a parameter passed to a function or a property getter/setter, including this and extension receiver parameters.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
index Int
0-based index of this parameter in the parameter list of its containing callable.
no setter
isOptional Boolean
Returns true if this parameter is optional and can be omitted when making a call via KCallable.callBy, or false otherwise.
no setter
isVararg Boolean
Returns true if this parameter is vararg.
no setter
kind KParameterKind
Kind of this parameter.
no setter
members Collection<KCallable>
Annotations which are present on this element.
no setterinherited
name String?
Name of this parameter as it was declared in the source code, or null if the parameter has no name or its name is not available at runtime.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type KType
Type of this parameter. For a vararg parameter, this is the type of the corresponding array, not the individual element.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited