type property
KType
get
type
Type of this parameter. For a vararg parameter,
this is the type of the corresponding array, not the individual element.
Implementation
KType get type;
Type of this parameter. For a vararg parameter,
this is the type of the corresponding array, not the individual element.
KType get type;