KParameterKind enum

Kind represents a particular position of the parameter declaration in the source code, such as an instance, an extension receiver parameter or a value parameter.

Inheritance
Available extensions

Values

INSTANCE → const KParameterKind

Instance required to make a call to the member, or an outer class instance for an inner class constructor.

EXTENSION_RECEIVER → const KParameterKind

Extension receiver of an extension function or property.

VALUE → const KParameterKind

Ordinary named value parameter.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<KParameterKind>
A constant List of the values in this enum, in order of their declaration.