KTypeParameter class abstract interface

Represents a declaration of a type parameter of a class or a callable.

See the Kotlin language documentation for more information.

Inheritance
Available extensions

Properties

hashCode int
The hash code for this object.
no setterinherited
isReified Boolean
Returns true if this type parameter is reified.
no setter
name String
The name of this type parameter as it was declared in the source code.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
starProjectedType KType

Available on KClassifier, provided by the KClassifierExtension extension

Creates an instance of KType with the given classifier, substituting all its type parameters with star projections.
no setter
upperBounds List<KType>
Upper bounds, or generic constraints imposed on this type parameter.
no setter
variance KVariance
Declaration-site variance of this type parameter.
no setter

Methods

createType({List<KTypeProjection> arguments = const [], List<Annotation> annotations = const [], Boolean nullable = false}) KType

Available on KClassifier, provided by the KClassifierExtension extension

Creates a KType instance with the given classifier, type arguments, nullability and annotations.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited