upperBounds property
Upper bounds, or generic constraints imposed on this type parameter.
See the Kotlin language documentation for more information.
Implementation
List<KType> get upperBounds;
Upper bounds, or generic constraints imposed on this type parameter.
See the Kotlin language documentation for more information.
List<KType> get upperBounds;