KTypeProjection typedef
Represents a type projection.
Type projection is usually the argument to another type in a type usage.
For example, in the type Array<out Number>, out Number
is the covariant projection of the type represented by the class Number.
Type projection is either the star projection, or an entity consisting of a specific type plus optional variance.
type- The type specified in the projection, or null if this is a star projection.variance- The use-site variance specified in the projection, or null if this is a star projection.
See the Kotlin language documentation for more information.
Implementation
typedef KTypeProjection = (KType?, KVariance?);