KVariance enum

Represents variance applied to a type parameter on the declaration site (declaration-site variance), or to a type in a projection (use-site variance).

See the Kotlin language documentation for more information.

Inheritance
Available extensions

Values

INVARIANT → const KVariance

The affected type parameter or type is invariant, which means it has no variance applied to it.

IN → const KVariance

The affected type parameter or type is contravariant.

Denoted by the in modifier in the source code.

OUT → const KVariance

The affected type parameter or type is covariant.

Denoted by the out modifier in the source code.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<KVariance>
A constant List of the values in this enum, in order of their declaration.