KVisibility enum

Visibility is an aspect of a Kotlin declaration regulating where that declaration is accessible in the source code. Visibility can be changed with one of the following modifiers: public, protected, internal, private.

Note that some Java visibilities such as package-private and protected (which also gives access to items from the same package) cannot be represented in Kotlin, so there's no KVisibility value corresponding to them.

See the Kotlin language documentation for more information.

Inheritance
Available extensions

Values

PUBLIC → const KVisibility

Visibility of declarations marked with the public modifier, or with no modifier at all.

PROTECTED → const KVisibility

Visibility of declarations marked with the protected modifier.

INTERNAL → const KVisibility

Visibility of declarations marked with the internal modifier.

PRIVATE → const KVisibility

Visibility of declarations marked with the private modifier.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<KVisibility>
A constant List of the values in this enum, in order of their declaration.