value property

T get value

Gets the lazily initialized value of the current Lazy instance.

Once the value was initialized it must not change during the rest of lifetime of this Lazy instance.

Implementation

T get value;