LazyThreadSafetyMode enum

Specifies how a Lazy instance synchronizes initialization among multiple threads.

Inheritance
Available extensions

Values

SYNCHRONIZED → const LazyThreadSafetyMode

Locks are used to ensure that only a single thread can initialize the Lazy instance.

PUBLICATION → const LazyThreadSafetyMode

Initializer function can be called several times on concurrent access to uninitialized Lazy instance value, but only the first returned value will be used as the value of Lazy instance.

NONE → const LazyThreadSafetyMode

No locks are used to synchronize an access to the Lazy instance value; if the instance is accessed from multiple threads, its behavior is undefined.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<LazyThreadSafetyMode>
A constant List of the values in this enum, in order of their declaration.