Long typedef
Long = int
Represents a 64-bit signed integer.
On the JVM, non-nullable values of this type are represented as values of the primitive type long.
Implementation
typedef Long = int;
Represents a 64-bit signed integer.
On the JVM, non-nullable values of this type are represented as values of the primitive type long.
typedef Long = int;