MathUtils extension

on

Properties

absoluteValue num

Available on num, provided by the MathUtils extension

Returns the absolute value of this value.
no setter
sign num

Available on num, provided by the MathUtils extension

Returns the sign of this value.
no setter

Methods

IEEErem(num x) num

Available on num, provided by the MathUtils extension

Computes the remainder of division of this value by the divisor value according to the IEEE 754 standard.
nextDown() num

Available on num, provided by the MathUtils extension

Returns the value nearest to this value in direction of negative infinity.
nextTowards(num to) num

Available on num, provided by the MathUtils extension

Returns the Double value nearest to this value in direction from this value towards the value to.
nextUp() num

Available on num, provided by the MathUtils extension

Returns the value nearest to this value in direction of positive infinity.
pow(num x) num

Available on num, provided by the MathUtils extension

Raises this value to the power x.
withSign(num sign) num

Available on num, provided by the MathUtils extension

Returns this value with the sign bit same as of the sign value.