nextTowards method

num nextTowards(
  1. num to
)

Returns the Double value nearest to this value in direction from this value towards the value to.

Implementation

num nextTowards(num to) => to.floorToDouble();