MemoryUsage class
This class represents statistics of memory usage in one memory pool.
- Annotations
Constructors
- MemoryUsage(Long totalObjectsSizeBytes)
-
This class represents statistics of memory usage in one memory pool.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalObjectsSizeBytes → Long
-
The total size of allocated objects.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited