totalObjectsSizeBytes property

Long totalObjectsSizeBytes
final

The total size of allocated objects.

System allocator overhead is not included, so it can not perfectly match the value received by os tools.

All alignment and auxiliary object headers are included.

Implementation

final Long totalObjectsSizeBytes;