appendCData method
Appends C data to the buffer, if data is null or count is non-positive - return.
Implementation
external fun appendCData(COpaquePointer? data, Int count);
Appends C data to the buffer, if data is null or count is non-positive - return.
external fun appendCData(COpaquePointer? data, Int count);