withBufferLocked<R> method

R withBufferLocked<R>(
  1. R block(
    1. ByteArray array,
    2. Int dataSize
    )
)

Executes provided block under lock with the raw data buffer.

Block is executed under the spinlock, and must be short.

Implementation

external R withBufferLocked<R>(
  R Function(ByteArray array, Int dataSize) block,
);