NativeConcurrentAnyExtension extension
- on
Properties
- isFrozen → Boolean
-
Available on Any, provided by the NativeConcurrentAnyExtension extension
Checks if given object is null or frozen or permanent (i.e. instantiated at compile-time).no setter
Methods
-
ensureNeverFrozen<
T> () → void -
Available on Any, provided by the NativeConcurrentAnyExtension extension
This function ensures that if we see such an object during freezing attempt - freeze fails and FreezingException is thrown. -
freeze<
T> () → T -
Available on Any, provided by the NativeConcurrentAnyExtension extension
Freezes object subgraph reachable from this object.