NoSuchFileException typedef
NoSuchFileException = PathNotFoundException
An exception class which is used when file to copy does not exist.
Implementation
typedef NoSuchFileException = PathNotFoundException;
An exception class which is used when file to copy does not exist.
typedef NoSuchFileException = PathNotFoundException;