NoSuchPropertyException class final

An exception that is thrown when the code tries to introspect a property of a class or a package and that class or the package no longer has that property.

Implemented types

Constructors

NoSuchPropertyException({Exception? cause})
const

Properties

cause Exception?
The original exception thrown by the JVM.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited