hours property
Returns a Duration equal to this number of hours.
Implementation
@Deprecated(
'Use num.hours extension property from Duration.Companion instead.',
)
Duration get hours => Duration(hours: toInt());
Returns a Duration equal to this number of hours.
@Deprecated(
'Use num.hours extension property from Duration.Companion instead.',
)
Duration get hours => Duration(hours: toInt());