ObjCName class

Instructs the Kotlin compiler to use a custom Objective-C and/or Swift name for this class, property, parameter or function.

Annotations
  • @Target([AnnotationTarget.CLASS, AnnotationTarget.PROPERTY, AnnotationTarget.VALUE_PARAMETER, AnnotationTarget.FUNCTION])
  • @experimentalObjCName

Constructors

ObjCName({Boolean exact = false, String name = '', String swiftName = ''})
Instructs the Kotlin compiler to use a custom Objective-C and/or Swift name for this class, property, parameter or function.
const

Properties

exact Boolean
Dpecifies if the name of a class should be interpreted as the exact name.
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
swiftName String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited