ObjCName constructor

const ObjCName({
  1. Boolean exact = false,
  2. String name = '',
  3. String swiftName = '',
})

Instructs the Kotlin compiler to use a custom Objective-C and/or Swift name for this class, property, parameter or function.

Implementation

const ObjCName({
  this.exact = false,
  this.name = '',
  this.swiftName = '',
});