exact property

Boolean exact
final

Dpecifies if the name of a class should be interpreted as the exact name.

E.g. the compiler won't add a top level prefix or the outer class names to exact names.

Implementation

final Boolean exact;