ObservableProperty<V> class abstract

Implements the core logic of a property delegate for a read/write property that calls callback functions when changed.

Inheritance

Constructors

ObservableProperty(V initialValue)
Implements the core logic of a property delegate for a read/write property that calls callback functions when changed.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
initialValue → V
The initial value of the property.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

afterChange(KProperty<Any> property, V oldValue, V newValue) → void
The callback which is called after the change of the property is made.
beforeChange(KProperty<Any> property, V oldValue, V newValue) Boolean
The callback which is called before a change to the property value is attempted.
getValue(Any? thisRef, KProperty<Any> property) → V
Returns the value of the property for the given object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setValue(Any? thisRef, KProperty<Any> property, V value) → void
Sets the value of the property for the given object.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited