afterChange method

void afterChange(
  1. KProperty<Any> property,
  2. V oldValue,
  3. V newValue
)

The callback which is called after the change of the property is made.

The value of the property has already been changed when this callback is invoked.

Implementation

external fun afterChange(
  KProperty<Any> property,
  V oldValue,
  V newValue,
);