ObsoleteWorkersApi class final
Marks all Worker-related API as obsolete.
Workers are considered obsolete: their API shape, design, and behaviour have known flaws and pitfalls that are impossible to address in Worker's current form.
Workers continue being supported and maintained, but they eventually will be replaced with threads API and then deprecated.
It is not recommended to expose workers in public API or to have high coupling with Workers API, and instead, we suggest encapsulating them in a domain-specific API to simplify future migration and reduce potential exposure to dangerous API.
- Annotations
-
- @Target([AnnotationTarget.CLASS, AnnotationTarget.ANNOTATION_CLASS, AnnotationTarget.PROPERTY, AnnotationTarget.FIELD, AnnotationTarget.LOCAL_VARIABLE, AnnotationTarget.VALUE_PARAMETER, AnnotationTarget.CONSTRUCTOR, AnnotationTarget.FUNCTION, AnnotationTarget.PROPERTY_GETTER, AnnotationTarget.PROPERTY_SETTER, AnnotationTarget.TYPEALIAS])
Constructors
- ObsoleteWorkersApi()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited