PI top-level constant
double
const PI
Ratio of the circumference of a circle to its diameter, approximately 3.14159.
Implementation
const double PI = math.pi;
Ratio of the circumference of a circle to its diameter, approximately 3.14159.
const double PI = math.pi;