ReadOnlyProperty<T, V> class abstract interface

Base interface that can be used for implementing property delegates of read-only properties.

This is provided only for convenience.

You don't have to extend this interface as long as your property delegate has methods with the same signatures.

Parameters:

  • T - the type of object which owns the delegated property.

  • V - the type of the property value.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getValue(T thisRef, KProperty<Any> property) → V
Returns the value of the property for the given object.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited