ReadWriteProperty<T, V> class abstract interface

Base interface that can be used for implementing property delegates of read-write properties.

This is provided only for convenience. You don't have to extend this interface as long as your property delegate has methods with the same signatures.

Parameters:

  • T - the type of object which owns the delegated property.

  • V - the type of the property value.

Inheritance
Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getValue(T thisRef, KProperty<Any> property) → V
Returns the value of the property for the given object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setValue(T thisRef, KProperty<Any> property, V value) → void
Sets the value of the property for the given object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited