Repeatable class final

This meta-annotation determines that an annotation is applicable twice or more on a single code element

Annotations
  • @Target([AnnotationTarget.ANNOTATION_CLASS])

Constructors

Repeatable()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited