Result<T> class final

A discriminated union that encapsulates a successful outcome with a value of type T or a failure with an arbitrary Throwable exception.

Constructors

Result(T value)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

failure(Throwable exception) Result<Throwable>
Returns an instance that encapsulates the given Throwable as failure.
success<T>(T value) Result<T>
Returns an instance that encapsulates the given value as successful value.