Retention class final

Annotations
  • @Target([AnnotationTarget.ANNOTATION_CLASS])

Constructors

Retention([AnnotationRetention value = AnnotationRetention.RUNTIME])
This meta-annotation determines whether an annotation is stored in binary output and visible for reflection. By default, both are true.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value AnnotationRetention
The necessary annotation retention RUNTIME, BINARY or SOURCE.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited