RootSetStatistics constructor

const RootSetStatistics({
  1. required Long globalReferences,
  2. required Long stableReferences,
  3. required Long stackReferences,
  4. required Long threadLocalReferences,
})

This class represents statistics of the root set for garbage collector run, separated by root set pools.

These nodes are assumed to be used, even if there are no references for them.

Implementation

const RootSetStatistics({
  required this.globalReferences,
  required this.stableReferences,
  required this.stackReferences,
  required this.threadLocalReferences,
});