globalReferences property
The number of objects in global variables.
The object is counted only if the variable is initialized.
Implementation
final Long globalReferences;
The number of objects in global variables.
The object is counted only if the variable is initialized.
final Long globalReferences;