stackReferences property

Long stackReferences
final

The number of objects referenced from the stack of any thread.

These are function local variables and different temporary values, as function call arguments and return values.

They would be automatically removed from the root set when a corresponding function call is finished.

Implementation

final Long stackReferences;