threadLocalReferences property

Long threadLocalReferences
final

The number of objects in global variables with @ThreadLocal annotation.

Object is counted once per each thread it was initialized in.

Implementation

final Long threadLocalReferences;