SharedImmutable class final

Note: this annotation has effect only in Kotlin/Native with legacy memory manager.

Marks a top level property with a backing field as immutable. It is possible to share the value of such property between multiple threads, but it becomes deeply frozen, so no changes can be made to its state or the state of objects it refers to.

The annotation has effect only in Kotlin/Native platform.

PLEASE NOTE THAT THIS ANNOTATION MAY GO AWAY IN UPCOMING RELEASES.

Since 1.7.20 usage of this annotation is deprecated.

See https://kotlinlang.org/docs/native-migration-guide.html for details.

Annotations

Constructors

SharedImmutable()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited