Short typedef
Short = int
Represents a 16-bit signed integer.
On the JVM, non-nullable values of this type are represented as values of the primitive type short.
Implementation
typedef Short = int;
Represents a 16-bit signed integer.
On the JVM, non-nullable values of this type are represented as values of the primitive type short.
typedef Short = int;