SweepStatistics class

This class represents statistics of sweeping in one memory pool.

Annotations

Constructors

SweepStatistics(Long keptCount, Long sweptCount)
This class represents statistics of sweeping in one memory pool.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
keptCount Long
The number of objects that were processed but kept alive.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sweptCount Long
The of objects that were freed.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited