toString method

String toString()
override

Returns the short description of this throwable consisting of the exception class name (fully qualified if possible) followed by the exception message if it is not null.

Implementation

external String toString();