TimedValue<T> typedef

TimedValue<T> = (Duration, T)

Data class representing a result of executing an action, along with the duration of elapsed time interval.

Implementation

typedef TimedValue<T> = (Duration, T);