Transient class final

Marks the JVM backing field of the annotated property as transient, meaning that it is not part of the default serialized form of the object.

Annotations
  • @Target([AnnotationTarget.FIELD])

Constructors

Transient()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited