Unit typedef
Unit = void
The type with only one value: the Unit object.
This type corresponds to the void type in Java.
Implementation
typedef Unit = void;
The type with only one value: the Unit object.
This type corresponds to the void type in Java.
typedef Unit = void;