WeekReference<T extends Any> class

Class WeakReference encapsulates weak reference to an object, which could be used to either retrieve a strong reference to an object, or return null, if object was already destroyed by the memory manager.

Annotations

Constructors

WeekReference(T referred)
Creates a weak reference object pointing to an object.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T?
Returns either reference to an object or null, if it was collected.
no setter

Methods

clear() → void
Clears reference to an object.
get() → T?
Returns either reference to an object or null, if it was collected.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited