park method

Boolean park({
  1. Boolean process = true,
  2. Int timeoutMicroseconds = 0,
})

Park execution of the current worker until a new request arrives or timeout specified in timeoutMicroseconds elapsed.

If process is true, pending queue elements are processed, including delayed requests.

Note that multiple requests could be processed this way.

Implementation

external Boolean park({
  Boolean process = true,
  Int timeoutMicroseconds = 0,
});