start static method

Worker start({
  1. Boolean errorReporting = true,
  2. String? name,
})

Start new scheduling primitive, such as thread, to accept new tasks via execute interface.

Typically new worker may be needed for computations offload to another core, for IO it may be better to use non-blocking IO combined with more lightweight coroutines.

Return worker object, usable across multiple concurrent contexts.

Implementation

external static Worker start({
  Boolean errorReporting = true,
  String? name,
});