afterClass top-level constant
AfterClass
const afterClass
Marks a function to be executed after a suite.
Not supported in Kotlin/Common.
Implementation
const afterClass = AfterClass();
Marks a function to be executed after a suite.
Not supported in Kotlin/Common.
const afterClass = AfterClass();