arrayOfNulls function

Array<void> arrayOfNulls(
  1. Int size
)

Returns an array of objects of the given type with the given size, initialized with null values.

Implementation

Array<Unit> arrayOfNulls(Int size) => Array.filled(size, null);