assertContentEquals<T> function

void assertContentEquals<T>({
  1. Iterable<T>? expected,
  2. Iterable<T>? actual,
  3. String? message,
})

Asserts that the expected iterable is structurally equal to the actual iterable, i.e. contains the same number of the same elements in the same order, with an optional message.

The elements are compared for equality with the equals function.

For floating point numbers it means that NaN is equal to itself and -0.0 is not equal to 0.0.

Implementation

Unit assertContentEquals<T>({
  Iterable<T>? expected,
  Iterable<T>? actual,
  String? message,
}) {}