assertFails function

Throwable assertFails(
  1. void block(), [
  2. String? message
])

Asserts that given function block fails by throwing an exception.

If the assertion fails, the specified message is used unless it is null as a prefix for the failure message.

Return an exception that was expected to be thrown and was successfully caught.

The returned exception can be inspected further, for example by asserting its property values.

Implementation

Throwable assertFails(
  Unit Function() block, [
  String? message,
]) {
  asserter.fail(message);
}