assertIs<T> function

T assertIs<T>(
  1. Any? value, [
  2. String? message
])

Asserts that value is of type T, with an optional message.

Note that due to type erasure the type check may be partial (e.g. assertIs<List<String>>(value) only checks for the class being List and not the type of its elements because it's erased).

Implementation

T assertIs<T>(
  Any? value, [
  String? message,
]) {
  t.expect(value, T, reason: message);
  return value as T;
}