assertIsNot<T> function

void assertIsNot<T>(
  1. Any? value, [
  2. String? message
])

Asserts that value is not of type T, with an optional message.

Note that due to type erasure the type check may be partial (e.g. assertIsNot<List<String>>(value) only checks for the class being List and not the type of its elements because it's erased).

Implementation

Unit assertIsNot<T>(
  Any? value, [
  String? message,
]) {
  return t.expect(value, T, reason: message);
}