assertNotNullNoInline<T extends Any, R> function

  1. @JvmName("assertNotNull")
  2. @Deprecated('Provided for binary compatibility')
void assertNotNullNoInline<T extends Any, R>(
  1. T? actual, {
  2. String? message,
  3. R block(
    1. T
    )?,
})

Asserts that the actual value is not null, with an optional message and a function block to process the not-null value.

Implementation

@JvmName("assertNotNull")
@Deprecated('Provided for binary compatibility')
Unit assertNotNullNoInline<T extends Any, R>(
  T? actual, {
  String? message,
  R Function(T)? block,
}) {
  return asserter.assertNotNull(message, actual);
}