atomicArray<T> function
Creates a new AtomicArray of the given size,
where each element is initialized by calling the given init function.
Implementation
external AtomicArray<T> atomicArray<T>(Int size, T Function(Int) init);
Creates a new AtomicArray of the given size,
where each element is initialized by calling the given init function.
external AtomicArray<T> atomicArray<T>(Int size, T Function(Int) init);