cast<T> function

T cast<T>(
  1. Any value
)

Casts the given value to the class represented by this T object.

Throws an exception if the value is null or if it is not an instance of this class.

Implementation

T cast<T>(Any value) => value as T;