experimentalStdlibApi top-level constant

ExperimentalStdlibApi const experimentalStdlibApi

This annotation marks the standard library API that is considered experimental and is not subject to the general compatibility guarantees given for the standard library: the behavior of such API may be changed or the API may be removed completely in any further release.

Implementation

const experimentalStdlibApi = ExperimentalStdlibApi();