getTimeMicros function
Gets current system time in microseconds since certain moment in the past, only delta between two subsequent calls makes sense.
Implementation
@Deprecated('Use measureTime() or TimeSource.Monotonic.markNow() instead.')
Long getTimeMicros() => DateTime.timestamp().microsecondsSinceEpoch;