jvmStatic top-level constant

JvmStatic const jvmStatic

Specifies that an additional static method needs to be generated from this element if it's a function.

If this element is a property, additional static getter/setter methods should be generated.

Implementation

const jvmStatic = JvmStatic();