mustBeDocumented top-level constant

MustBeDocumented const mustBeDocumented

This meta-annotation determines that an annotation is a part of public API and therefore should be included in the generated documentation for the element to which the annotation is applied.

Implementation

const mustBeDocumented = MustBeDocumented();