println function
Prints the given message and the line separator to the standard output stream.
Implementation
Unit println(Any message) => print(message);
Prints the given message and the line separator to the standard output stream.
Unit println(Any message) => print(message);