readln function

String readln()

Reads a line of input from the standard input stream and returns it, or throws a RuntimeException if EOF has already been reached when readln is called.

Implementation

String readln() => readline() ?? '';