transient top-level constant

Transient const transient

Marks the JVM backing field of the annotated property as transient, meaning that it is not part of the default serialized form of the object.

Implementation

const transient = Transient();