AnnotationTarget enum
Contains the list of code elements which are the possible annotation targets.
Values
- CLASS → const AnnotationTarget
-
Class, interface or object, annotation class is also included.
- ANNOTATION_CLASS → const AnnotationTarget
-
Annotation class only.
- TYPE_PARAMETER → const AnnotationTarget
-
Generic type parameter.
- PROPERTY → const AnnotationTarget
-
Property.
- FIELD → const AnnotationTarget
-
Field, including property's backing field.
- LOCAL_VARIABLE → const AnnotationTarget
-
Local variable.
- VALUE_PARAMETER → const AnnotationTarget
-
Value parameter of a function or a constructor.
- CONSTRUCTOR → const AnnotationTarget
-
Constructor only (primary or secondary).
- FUNCTION → const AnnotationTarget
-
Function (constructors are not included).
- PROPERTY_GETTER → const AnnotationTarget
-
Property getter only.
- PROPERTY_SETTER → const AnnotationTarget
-
Property setter only.
- TYPE → const AnnotationTarget
-
Type usage.
- EXPRESSION → const AnnotationTarget
-
Any expression.
- FILE → const AnnotationTarget
-
File.
- TYPEALIAS → const AnnotationTarget
-
Type alias.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AnnotationTarget> - A constant List of the values in this enum, in order of their declaration.