Asserter class abstract interface

Abstracts the logic for performing assertions.

Specific implementations of Asserter can use JUnit or TestNG assertion facilities.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

assertEquals(String? message, Any? expected, Any? actual) → void
Asserts that the specified values are equal.
assertNotEquals(String? message, Any? illegal, Any? actual) → void
Asserts that the specified values are not equal.
assertNotNull(String? message, Any? actual) → void
Asserts that the specified value is not null.
assertNotSame(String? message, Any? illegal, Any? actual) → void
Asserts that the specified values are not the same instance.
assertNull(String? message, Any? actual) → void
Asserts that the specified value is null.
assertSame(String? message, Any? illegal, Any? actual) → void
Asserts that the specified values are the same instance.
assertTrue(Boolean actual, {String? message, String? lazyMessage()}) → void
Asserts that the specified value is true.
fail(String? message, [Throwable? cause]) → Never
Fails the current test with the specified message (and cause exception).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited