ComparisonUtils<T extends Comparable<T> > extension
- on
-
- Comparable<
T>
- Comparable<
Methods
-
coerceAtLeast(
T minimumValue) → Comparable< T> -
Available on Comparable<
Ensures that this value is not less than the specifiedT> , provided by the ComparisonUtils extensionminimumValue. -
coerceAtMost(
T maximumValue) → Comparable< T> -
Available on Comparable<
Ensures that this value is not greater than the specifiedT> , provided by the ComparisonUtils extensionmaximumValue. -
coerceIn(
T minimumValue, T maximumValue) → Comparable< T> -
Available on Comparable<
Ensures that this value lies between theT> , provided by the ComparisonUtils extensionminimumValueandmaximumValue.
Operators
-
operator <(
T other) → bool -
Available on Comparable<
T> , provided by the ComparisonUtils extension -
operator <=(
T other) → bool -
Available on Comparable<
T> , provided by the ComparisonUtils extension -
operator >(
T other) → bool -
Available on Comparable<
T> , provided by the ComparisonUtils extension -
operator >=(
T other) → bool -
Available on Comparable<
T> , provided by the ComparisonUtils extension