CopyActionResult enum
The result of the copyAction function passed to Path.copyToRecursively
that specifies further actions when copying an entry.
- Inheritance
- Available extensions
- Annotations
Values
- CONTINUE → const CopyActionResult
-
Continue with the next entry in the traversal order.
- SKIP_SUBTREE → const CopyActionResult
-
Skip the directory content, continue with the next entry outside the directory in the traversal order. For files this option is equivalent to CONTINUE.
- TERMINATE → const CopyActionResult
-
Stop the recursive copy function. The function will return without throwing exception.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
CopyActionResult> - A constant List of the values in this enum, in order of their declaration.