Delegates class sealed
Standard property delegates.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
notNull<
T extends Any> () → ReadWriteProperty< Any?, T> - Returns a property delegate for a read/write property with a non-null value that is initialized not during object construction time but at a later time.
-
observable<
T> (T initialValue, void onChange(KProperty< T> property, T oldValue, T newValue)) → ReadWriteProperty<Any?, T> - Returns a property delegate for a read/write property that calls a specified callback function when changed.
-
vetoable<
T> (T initialValue, Boolean onChange(KProperty< T> property, T oldValue, T newValue)) → ReadWriteProperty<Any?, T> - Returns a property delegate for a read/write property that calls a specified callback function when changed, allowing the callback to veto the modification.