notNull<T extends Any> static method
Returns a property delegate for a read/write property with a non-null value that is initialized not during object construction time but at a later time.
Trying to read the property before the initial value has been assigned results in an exception.
Implementation
external static ReadWriteProperty<Any?, T> notNull<T extends Any>();