DeprecatedSinceKotlin class final
Marks the annotated declaration as deprecated.
In contrast to Deprecated, severity of the reported diagnostic is not a constant value,
but differs depending on the API version of the usage
(the value of the -api-version argument when compiling the module where the usage is located).
If the API version is greater or equal than hiddenSince, the declaration will not be accessible from the code (as if it was deprecated with level DeprecationLevel.HIDDEN), otherwise if the API version is greater or equal than errorSince, the usage will be marked as an error (as with DeprecationLevel.ERROR), otherwise if the API version is greater or equal than warningSince, the usage will be marked as a warning (as with DeprecationLevel.WARNING), otherwise the annotation is ignored.
- Annotations
-
- @Target([AnnotationTarget.CLASS, AnnotationTarget.FUNCTION, AnnotationTarget.PROPERTY, AnnotationTarget.ANNOTATION_CLASS, AnnotationTarget.CONSTRUCTOR, AnnotationTarget.PROPERTY_SETTER, AnnotationTarget.PROPERTY_GETTER, AnnotationTarget.TYPEALIAS])
- @mustBeDocumented
Constructors
- DeprecatedSinceKotlin([String errorSince = '', String warningSince = ''])
-
Marks the annotated declaration as deprecated.
const
Properties
- errorSince → String
-
The version, since which this deprecation should be reported as a error.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
The version, since which the annotated declaration should not be available in code.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- warningSince → String
-
The version, since which this deprecation should be reported as a warning.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited