Serves as a bridge to a testing framework.
The tests structure is defined using internal functions suite and test, which delegate to corresponding functions of a FrameworkAdapter. Sample test layout:
suite('a suite', false, () {
suite('a subsuite', false, () {
test('a test', false, () {...});
test('an ignored/pending test', true, () {...});
});
suite('an ignored/pending test', true, () {...});
});
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
suite(
String name, Boolean ignored, void suiteFn()) → void - Declares a test suite.
-
test(
String name, Boolean ignored, void testFn()) → void - Declares a test.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited