Future<T> class
Constructors
- Future()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → Int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → FutureState
-
A FutureState of this future
no setter
- value → T
-
The result of the future computation.
no setter
Methods
-
consume<
R> (R code(T)) → R - Blocks execution until the future is ready.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns a string representation of the object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited