lastGCInfo property
Returns statistics of the last finished garbage collection run.
This information is supposed to be used for testing and debugging purposes only
Implementation
external final GCInfo? lastGCInfo;
Returns statistics of the last finished garbage collection run.
This information is supposed to be used for testing and debugging purposes only
external final GCInfo? lastGCInfo;