GCInfo class
This class represents statistics about the single run of the garbage collector.
It is supposed to be used for testing and debugging purposes only.
- Annotations
Constructors
-
GCInfo({required Long endTimeNs, required Long epoch, required Long firstPauseEndTimeNs, required Long firstPauseRequestTimeNs, required Long firstPauseStartTimeNs, required Long markedCount, required Map<
String, MemoryUsage> memoryUsageAfter, required Map<String, MemoryUsage> memoryUsageBefore, Long? postGcCleanupTimeNs, required RootSetStatistics rootSet, Long? secondPauseEndTimeNs, Long? secondPauseRequestTimeNs, Long? secondPauseStartTimeNs, required Long startTimeNs, required Map<String, SweepStatistics> sweepStatistics}) -
This class represents statistics about the single run of the garbage collector.
const
Properties
- endTimeNs → Long
-
Time, when garbage collector run is ended,
measured by
kotlin.system.getTimeNanos.final - epoch → Long
-
ID of garbage collector run.
final
- firstPauseEndTimeNs → Long
-
Time, when mutator threads are unsuspended for the first time,
mesured by
kotlin.system.getTimeNanos.final - firstPauseRequestTimeNs → Long
-
Time, when the garbage collector thread requested
suspension of mutator threads for the first time,
mesured by
kotlin.system.getTimeNanos.final - firstPauseStartTimeNs → Long
-
Time, when mutator threads are suspended for the first time,
mesured by
kotlin.system.getTimeNanos.final - hashCode → int
-
The hash code for this object.
no setterinherited
- markedCount → Long
-
How many objects were processed during marking phase.
final
-
memoryUsageAfter
→ Map<
String, MemoryUsage> -
Memory usage at the start of garbage collector run, separated by memory pools.
final
-
memoryUsageBefore
→ Map<
String, MemoryUsage> -
Memory usage at the end of garbage collector run, separated by memory pools.
final
- postGcCleanupTimeNs → Long?
-
Time, when all memory is reclaimed,
measured by
kotlin.system.getTimeNanos.final - rootSet → RootSetStatistics
-
The number of objects in each root set pool.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondPauseEndTimeNs → Long?
-
Time, when mutator threads are unsuspended for the second time,
mesured by
kotlin.system.getTimeNanos.final - secondPauseRequestTimeNs → Long?
-
Time, when the garbage collector thread requested
suspension of mutator threads for the second time,
mesured by
kotlin.system.getTimeNanos.final - secondPauseStartTimeNs → Long?
-
Time, when mutator threads are suspended for the second time,
mesured by
kotlin.system.getTimeNanos.final - startTimeNs → Long
-
Time, when garbage collector run is started,
meausered by
kotlin.system.getTimeNanos.final -
sweepStatistics
→ Map<
String, SweepStatistics> -
Sweeping statistics separated by memory pools.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited