endTimeNs property
Time, when garbage collector run is ended,
measured by kotlin.system.getTimeNanos.
After this point, most of the memory is reclaimed, and a new garbage collector run can start.
Implementation
final Long endTimeNs;
Time, when garbage collector run is ended,
measured by kotlin.system.getTimeNanos.
After this point, most of the memory is reclaimed, and a new garbage collector run can start.
final Long endTimeNs;