IllegalCallableAccessException class final
An exception that is thrown when call is invoked on a callable
or get or set is invoked on a property
and that callable is not accessible (in JVM terms) from the calling method.
- Implemented types
Constructors
- IllegalCallableAccessException({Exception? cause})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited