IndexedValue<T> typedef
IndexedValue<T> = (Int, T)
Data class representing a value from a collection or sequence, along with its index in that collection or sequence.
Implementation
typedef IndexedValue<T> = (Int, T);