InvalidMutabilityException class
Exception thrown whenever we attempt to mutate frozen objects.
- Inheritance
-
- Object
- RuntimeException
- InvalidMutabilityException
Constructors
- InvalidMutabilityException({String? message})
-
Exception thrown whenever we attempt to mutate frozen objects.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited