JvmRepeatable typedef

JvmRepeatable = Repeatable

Makes the annotation class repeatable in Java and Kotlin.

A repeatable annotation can be applied more than once on the same element.

Implementation

typedef JvmRepeatable = Repeatable;