parameters property
List<KParameter>
get
parameters
Parameters required to make a call to this callable.
If this callable requires a this instance or an extension receiver parameter,
they come first in the list in that order.
Implementation
List<KParameter> get parameters;