KCallableExtension extension
- on
Properties
- extensionReceiverParameter → KParameter?
-
Available on KCallable, provided by the KCallableExtension extension
Returns a parameter representing the extension receiver instance needed to call this callable, ornullif this callable is not an extension.no setter - instanceParameter → KParameter?
-
Available on KCallable, provided by the KCallableExtension extension
Returns a parameter representing thethisinstance needed to call this callable, ornullif this callable is not a member of a class and thus doesn't take such parameter.no setter - isAccessible → Boolean
-
Available on KCallable, provided by the KCallableExtension extension
Provides a way to suppress JVM access checks for a callable.no setter -
valueParameters
→ List<
KParameter> -
Available on KCallable, provided by the KCallableExtension extension
Returns parameters of this callable, excluding thethisinstance and the extension receiver parameter.no setter
Methods
-
callSuspend<
R> (Array< Any?> args) → R -
Available on KCallable, provided by the KCallableExtension extension
Calls a callable in the current suspend context. -
callSuspendBy<
R> (Map< KParameter, Any?> args) → R -
Available on KCallable, provided by the KCallableExtension extension
Calls a callable in the current suspend context. -
findParameterByName(
String name) → KParameter? -
Available on KCallable, provided by the KCallableExtension extension