KClassifierExtension extension
- on
Properties
- starProjectedType → KType
-
Available on KClassifier, provided by the KClassifierExtension extension
Creates an instance of KType with the given classifier, substituting all its type parameters with star projections.no setter
Methods
-
createType(
{List< KTypeProjection> arguments = const [], List<Annotation> annotations = const [], Boolean nullable = false}) → KType -
Available on KClassifier, provided by the KClassifierExtension extension
Creates a KType instance with the given classifier, type arguments, nullability and annotations.