KotlinVersion class final
Represents a version of the Kotlin standard library.
major, minor and patch are integer components of a version, they must be non-negative and not greater than 255 MAX_COMPONENT_VALUE.
Constructors
- KotlinVersion({required Int major, required Int minor, Int patch = 0})
-
Creates a version from major and minor components, leaving patch component zero.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- CURRENT → const KotlinVersion
- Returns the current version of the Kotlin standard library.
- MAX_COMPONENT_VALUE → const Int
- Maximum value a version component can have, a constant value 255.