Represents a value with lazy initialization.
To create an instance of Lazy use the lazy function.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → T
-
Gets the lazily initialized value of the current Lazy instance.
no setter
Methods
-
isInitialized(
) → Boolean -
Returns
trueif a value for this Lazy instance has been already initialized, andfalseotherwise. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited