MathUtils extension
- on
Properties
Methods
-
IEEErem(
num x) → num - Computes the remainder of division of this value by the divisor value according to the IEEE 754 standard.
-
nextDown(
) → num - Returns the value nearest to this value in direction of negative infinity.
-
nextTowards(
num to) → num -
Available on num, provided by the MathUtils extension
Returns the Double value nearest to this value in direction from this value towards the valueto. -
nextUp(
) → num - Returns the value nearest to this value in direction of positive infinity.
-
pow(
num x) → num - Raises this value to the power x.
-
withSign(
num sign) → num -
Available on num, provided by the MathUtils extension
Returns this value with thesignbit same as of thesignvalue.