withPointerLocked<R> method

R withPointerLocked<R>(
  1. R block(
    1. COpaquePointer,
    2. Int dataSize
    )
)

Executes provided block under lock with raw pointer to the data stored in the buffer.

Block is executed under the spinlock, and must be short.

Implementation

external R withPointerLocked<R>(
  R Function(COpaquePointer, Int dataSize) block,
);