ObjCName constructor
Instructs the Kotlin compiler to use a custom Objective-C and/or Swift name for this class, property, parameter or function.
Implementation
const ObjCName({
this.exact = false,
this.name = '',
this.swiftName = '',
});
Instructs the Kotlin compiler to use a custom Objective-C and/or Swift name for this class, property, parameter or function.
const ObjCName({
this.exact = false,
this.name = '',
this.swiftName = '',
});