exact property
Dpecifies if the name of a class should be interpreted as the exact name.
E.g. the compiler won't add a top level prefix or the outer class names to exact names.
Implementation
final Boolean exact;
Dpecifies if the name of a class should be interpreted as the exact name.
E.g. the compiler won't add a top level prefix or the outer class names to exact names.
final Boolean exact;