OnErrorResult enum
The result of the onError function passed to Path.copyToRecursively
that specifies further actions when an exception occurs.
- Inheritance
- Available extensions
- Annotations
Values
- SKIP_SUBTREE → const OnErrorResult
-
If the entry that caused the error is a directory, skip the directory and its content, and continue with the next entry outside this directory in the traversal order. Otherwise, skip this entry and continue with the next entry in the traversal order.
- TERMINATE → const OnErrorResult
-
Stop the recursive copy function. The function will return without throwing exception. To terminate the function with an exception rethrow instead.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
OnErrorResult> - A constant List of the values in this enum, in order of their declaration.