PathWalkOption enum
An enumeration to provide walk options for Path.walk function. The options can be combined to form the walk order and behavior needed.
Note that this enumeration is not exhaustive and new cases might be added in the future.
- Inheritance
- Available extensions
- Annotations
Values
- INCLUDE_DIRECTORIES → const PathWalkOption
-
Visits directories as well.
- BREADTH_FIRST → const PathWalkOption
-
Walks in breadth-first order.
- FOLLOW_LINKS → const PathWalkOption
-
Follows symbolic links to the directories they point to.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PathWalkOption> - A constant List of the values in this enum, in order of their declaration.