Base interface that can be used for implementing property delegate providers.
This is provided only for convenience. You don't have to extend this interface as long as your delegate provider has a method with the same signature.
Parameters:
-
T- the type of object which owns the delegated property. -
D- the type of property delegates this provider provides.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
provideDelegate(
T thisRef, KProperty< Any> property) → D - Returns the delegate of the property for the given object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited