RootSetStatistics class
This class represents statistics of the root set for garbage collector run, separated by root set pools.
These nodes are assumed to be used, even if there are no references for them.
- Annotations
Constructors
- RootSetStatistics({required Long globalReferences, required Long stableReferences, required Long stackReferences, required Long threadLocalReferences})
-
This class represents statistics of the root set
for garbage collector run, separated by root set pools.
const
Properties
- globalReferences → Long
-
The number of objects in global variables.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stableReferences → Long
-
The number of objects referenced by
kotlinx.cinterop.StableRef.final - stackReferences → Long
-
The number of objects referenced from the stack of any thread.
final
- threadLocalReferences → Long
-
The number of objects in global variables with
@ThreadLocalannotation.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited