Target class final
This meta-annotation indicates the kinds of code elements which are possible targets of an annotation.
If the target meta-annotation is not present on an annotation declaration,
the annotation is applicable to the following elements:
CLASS, PROPERTY, FIELD, LOCAL_VARIABLE, VALUE_PARAMETER,
CONSTRUCTOR, FUNCTION, PROPERTY_GETTER, PROPERTY_SETTER.
Constructors
-
Target(Array<
AnnotationTarget> allowedTargets) -
This meta-annotation indicates the kinds of code elements
which are possible targets of an annotation.
const
Properties
-
allowedTargets
→ Array<
AnnotationTarget> -
The list of allowed annotation targets.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited