Throwable class base
The base class for all errors and exceptions.
Only instances of this class can be thrown or caught.
Constructors
Properties
Methods
-
getStackTrace(
) → Array< String> - Returns an array of stack trace strings representing the stack trace pertaining to this throwable.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
printStackTrace(
) → void - Prints the detailed description of this throwable to the standard error output.
-
toString(
) → String -
Returns the short description of this throwable consisting
of the exception class name (fully qualified if possible)
followed by the exception message if it is not null.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited