current property
Worker
get
current
Return the current worker.
Worker context is accessible to any valid Kotlin context, but only actual active worker produced with Worker.start automatically processes execution requests.
For other situations processQueue must be called explicitly to process request queue.
Return current worker object, usable across multiple concurrent contexts.
Implementation
external static Worker get current;