Returns the cube root of x.
x
For any x, cbrt(-x) == -cbrt(x).
cbrt(-x) == -cbrt(x)
That is, the cube root of a negative value is the negative of the cube root of that value's magnitude.
num cbrt(num x) => math.sqrt(x) / 3;