contravariant function
Creates a contravariant projection of a given type,
denoted by the in modifier applied to a type.
For example, in the type MutableList<in Number>,
in Number is a contravariant projection of the type of class Number.
Implementation
KTypeProjection contravariant(KType type) => (type, KVariance.IN);