covariant function
Creates a covariant projection of a given type,
denoted by the out modifier applied to a type.
For example, in the type Array<out Number>, out Number
is a covariant projection of the type of class Number.
Implementation
KTypeProjection covariant(KType type) => (type, KVariance.OUT);