expect<T> function
Asserts that given function block returns the given expected value and use the given message if it fails.
Implementation
Unit expect<T>(
T expected,
Unit Function() block, {
String? message,
}) {
t.test(message, block);
}