experimentalNativeApi top-level constant
ExperimentalNativeApi
const experimentalNativeApi
This annotation marks the Kotlin/Native-only standard library API that is considered experimental and is not subject to the general compatibility guarantees given for the standard library: the behavior of such API may be changed or the API may be removed completely in any further release.
Implementation
const experimentalNativeApi = ExperimentalNativeApi();