experimentalReflectionOnLambdas top-level constant
ExperimentalReflectionOnLambdas
const experimentalReflectionOnLambdas
This annotation marks the experimental kotlin-reflect API that allows to approximate a Kotlin lambda or a function expression instance to a KFunction instance.
The behavior of this API may be changed or the API may be removed completely in any further release.
Implementation
const experimentalReflectionOnLambdas = ExperimentalReflectionOnLambdas();