invariant function
Creates an invariant projection of a given type.
Invariant projection is just the type itself, without any use-site variance modifiers applied to it.
For example, in the type Set<String>, String
is an invariant projection of the type represented by the class String.
Implementation
KTypeProjection invariant(KType type) => (type, KVariance.INVARIANT);