readline function
Reads a line of input from the standard input stream.
Return the line read or null if the input stream
is redirected to a file and the end of file has been reached.
Implementation
String? readline() => stdin.readLineSync(encoding: utf8);