threadLocal top-level constant
ThreadLocal
const threadLocal
Marks a top level property with a backing field or an object as thread local.
The object remains mutable and it is possible to change its state, but every thread will have a distinct copy of this object, so changes in one thread are not reflected in another.
Implementation
const threadLocal = ThreadLocal();