todo function

void todo(
  1. void block()
)

Takes the given block of test code and doesn't execute it.

This keeps the code under test referenced, but doesn't actually test it until it is implemented.

Implementation

Unit todo(Unit Function() block) => println('TODO at $block');