volatile top-level constant
Volatile
const volatile
Marks the backing field of the annotated var property as volatile,
meaning that reads and writes to this field are atomic
and writes are always made visible to other threads.
Implementation
const volatile = Volatile();